@@ -41,6 +41,12 @@ class Flavor(audobject.Object):
         sampling_rate: sampling rate in Hz, one of
             ``8000``, ``16000``, ``22500``, ``44100``, ``48000``
 
+    Raises:
+        ValueError: if a non-supported ``bit_depth``,
+            ``format``,
+            or ``sampling_rate``
+            is requested
+
     """
     def __init__(
             self,
@@ -248,8 +254,8 @@ class Flavor(audobject.Object):
                 and the input format is not WAV or FLAC
 
         """
-        src_path = audeer.safe_path(src_path)
-        dst_path = audeer.safe_path(dst_path)
+        src_path = audeer.path(src_path)
+        dst_path = audeer.path(dst_path)
 
         # verify that extension matches the output format
         src_ext = audeer.file_extension(src_path).lower()
