@@ -61,6 +61,22 @@ def fixture_publish_db():
         'filewise',
         num_files=[1, 2, 3],
     )
+    audformat.testing.add_misc_table(
+        db,
+        'misc-in-scheme',
+        pd.Index([0, 1, 2], dtype='Int64', name='idx'),
+        columns={'emotion': ('scheme', None)}
+    )
+    audformat.testing.add_misc_table(
+        db,
+        'misc-not-in-scheme',
+        pd.Index([0, 1, 2], dtype='Int64', name='idx'),
+        columns={'emotion': ('scheme', None)}
+    )
+    db.schemes['misc'] = audformat.Scheme(
+        'int',
+        labels='misc-in-scheme',
+    )
     db.save(DB_ROOT)
     audformat.testing.create_audio_files(db)
 
@@ -93,6 +109,8 @@ def test_load_on_demand():
 
     assert db['table1'] == db_original['table1']
     assert db['table2'] == db_original['table2']
+    assert db['misc-in-scheme'] == db_original['misc-in-scheme']
+    assert db['misc-not-in-scheme'] == db_original['misc-not-in-scheme']
     pd.testing.assert_index_equal(db.files, db_original.files)
     assert not db.meta['audb']['complete']
 
@@ -106,7 +124,9 @@ def test_load_on_demand():
     )
 
     assert db['table1'] == db_original['table1']
+    assert db['misc-in-scheme'] == db_original['misc-in-scheme']
     assert 'table2' not in db.tables
+    assert 'misc-not-in-scheme' not in db.misc_tables
     pd.testing.assert_index_equal(db.files, db_original['table1'].files)
     assert not db.meta['audb']['complete']
 
@@ -120,7 +140,9 @@ def test_load_on_demand():
     )
 
     assert db['table1'] == db_original['table1']
+    assert db['misc-in-scheme'] == db_original['misc-in-scheme']
     assert 'table2' not in db.tables
+    assert 'misc-not-in-scheme' not in db.misc_tables
     pd.testing.assert_index_equal(db.files, db_original['table1'].files)
     assert not db.meta['audb']['complete']
 
@@ -133,7 +155,9 @@ def test_load_on_demand():
     )
 
     assert db['table1'] == db_original['table1']
+    assert db['misc-in-scheme'] == db_original['misc-in-scheme']
     assert 'table2' not in db.tables
+    assert 'misc-not-in-scheme' not in db.misc_tables
     pd.testing.assert_index_equal(db.files, db_original['table1'].files)
     assert not db.meta['audb']['complete']
 
@@ -151,6 +175,8 @@ def test_load_on_demand():
 
     assert db['table1'] == db_original['table1']
     assert db['table2'] == db_original['table2']
+    assert db['misc-in-scheme'] == db_original['misc-in-scheme']
+    assert db['misc-not-in-scheme'] == db_original['misc-not-in-scheme']
     pd.testing.assert_index_equal(db.files, db_original.files)
     assert not db.meta['audb']['complete']
 
@@ -164,6 +190,8 @@ def test_load_on_demand():
 
     assert 'table1' in db.tables
     assert 'table2' in db.tables
+    assert 'misc-in-scheme' in db.misc_tables
+    assert 'misc-not-in-scheme' in db.misc_tables
     pd.testing.assert_index_equal(
         db.files,
         audformat.filewise_index(['audio/000.wav', 'audio/001.wav']),
@@ -179,10 +207,26 @@ def test_load_on_demand():
     )
 
     assert 'table1' not in db.tables
+    assert 'misc-not-in-scheme' not in db.misc_tables
+    assert db['misc-in-scheme'] == db_original['misc-in-scheme']
     assert db['table2'] == db_original['table2']
     pd.testing.assert_index_equal(db.files, db_original['table2'].files)
     assert db.meta['audb']['complete']
 
+    db = audb.load(
+        DB_NAME,
+        version=DB_VERSION,
+        tables=['misc-not-in-scheme'],
+        full_path=False,
+        verbose=False,
+    )
+
+    assert 'table1' not in db.tables
+    assert 'table2' not in db.tables
+    assert db['misc-in-scheme'] == db_original['misc-in-scheme']
+    assert db['misc-not-in-scheme'] == db_original['misc-not-in-scheme']
+    assert db.meta['audb']['complete']
+
     db = audb.load(
         DB_NAME,
         version=DB_VERSION,
