@@ -4,6 +4,7 @@ import re
 import shutil
 
 import numpy as np
+import pandas as pd
 import pytest
 
 import audbackend
@@ -64,15 +65,36 @@ def fixture_publish_db():
         num_files=5,
         columns={'emotion': ('scheme', None)}
     )
+    audformat.testing.add_misc_table(
+        db,
+        'misc-in-scheme',
+        pd.Index([0, 1, 2], dtype='Int64', name='idx'),
+        columns={'emotion': ('scheme', None)}
+    )
+    audformat.testing.add_misc_table(
+        db,
+        'misc-not-in-scheme',
+        pd.Index([0, 1, 2], dtype='Int64', name='idx'),
+        columns={'emotion': ('scheme', None)}
+    )
     db.schemes['speaker'] = audformat.Scheme(
         labels=['adam', '11']
     )
+    db.schemes['misc'] = audformat.Scheme(
+        'int',
+        labels='misc-in-scheme',
+    )
     db['files'] = audformat.Table(db.files)
     db['files']['speaker'] = audformat.Column(scheme_id='speaker')
     db['files']['speaker'].set(
         ['adam', 'adam', 'adam', '11'],
         index=audformat.filewise_index(db.files[:4]),
     )
+    db['files']['misc'] = audformat.Column(scheme_id='misc')
+    db['files']['misc'].set(
+        [0, 1, 1, 2],
+        index=audformat.filewise_index(db.files[:4]),
+    )
     db.save(
         DB_ROOT_VERSION['1.0.0'],
         storage_format=audformat.define.TableStorageFormat.PICKLE,
@@ -113,15 +135,36 @@ def fixture_publish_db():
         num_files=5,
         columns={'emotion': ('scheme', None)}
     )
+    audformat.testing.add_misc_table(
+        db,
+        'misc-in-scheme',
+        pd.Index([0, 1, 2], dtype='Int64', name='idx'),
+        columns={'emotion': ('scheme', None)}
+    )
+    audformat.testing.add_misc_table(
+        db,
+        'misc-not-in-scheme',
+        pd.Index([0, 1, 2], dtype='Int64', name='idx'),
+        columns={'emotion': ('scheme', None)}
+    )
     db.schemes['speaker'] = audformat.Scheme(
         labels=['adam', '11']
     )
+    db.schemes['misc'] = audformat.Scheme(
+        'int',
+        labels='misc-in-scheme',
+    )
     db['files'] = audformat.Table(db.files)
     db['files']['speaker'] = audformat.Column(scheme_id='speaker')
     db['files']['speaker'].set(
         ['adam', 'adam', 'adam', '11'],
         index=audformat.filewise_index(db.files[:4]),
     )
+    db['files']['misc'] = audformat.Column(scheme_id='misc')
+    db['files']['misc'].set(
+        [0, 1, 1, 2],
+        index=audformat.filewise_index(db.files[:4]),
+    )
     db.save(DB_ROOT_VERSION['6.0.0'])
     audformat.testing.create_audio_files(db)
     db.map_files(lambda x: os.path.join(db.root, x))  # make paths absolute
